@@ -42,6 +42,8 @@ pub const PIXELWIDTH: u32 = 0xB0;
 pub const PIXELHEIGHT: u32 = 0xBA;
 pub const DISPLAYWIDTH: u32 = 0x54B0;
 pub const DISPLAYHEIGHT: u32 = 0x54BA;
+pub const INTERLACED: u32 = 0x9A;
+pub const STEREOMODE: u32 = 0x53B8;
 pub const AUDIO: u32 = 0xE1;
 pub const SAMPLINGFREQUENCY: u32 = 0xB5;
 pub const CHANNELS: u32 = 0x9F;
